# Official React SDK for [Stream Video](https://getstream.io/video/sdk/react/)

<img src="../../.readme-assets/Github-Graphic-React.jpg" alt="Stream Video for React Header image" style="box-shadow: 0 3px 10px rgb(0 0 0 / 0.2); border-radius: 1rem" />

## **Quick Links**

- [Register](https://getstream.io/chat/trial/) to get an API key for Stream Video
- [React Video Tutorial](https://getstream.io/video/sdk/react/tutorial/video-calling/)
- [Sample application](https://getstream.io/video/demos/)

## What is Stream?

Stream allows developers to rapidly deploy scalable feeds, chat messaging and video with an industry leading 99.999% uptime SLA guarantee.

With Stream's video components, you can use their SDK to build in-app video calling, audio rooms, audio calls, or live streaming. The best place to get started is with their tutorials:

- [Video & Audio Calling Tutorial](https://getstream.io/video/sdk/react/tutorial/video-calling/)
- [Audio Rooms Tutorial](https://getstream.io/video/sdk/react/tutorial/audio-room/)
- [Livestreaming Tutorial](https://getstream.io/video/sdk/react/tutorial/livestreaming/)

Stream provides UI components and state handling that make it easy to build video calling for your app. All calls run on Stream's network of edge servers around the world, ensuring optimal latency and reliability.

## 👩‍💻 Free for Makers 👨‍💻

Stream is free for most side and hobby projects. To qualify, your project/company needs to have < 5 team members and < $10k in monthly revenue. Makers get $100 in monthly credit for video for free.

## 💡 Supported Features 💡

Here are some of the features we support:

- Developer experience: Great SDKs, docs, tutorials and support so you can build quickly
- Edge network: Servers around the world ensure optimal latency and reliability
- Chat: Stored chat, reactions, threads, typing indicators, URL previews etc
- Security & Privacy: Based in USA and EU, Soc2 certified, GDPR compliant
- Dynascale: Automatically switch resolutions, fps, bitrate, codecs and paginate video on large calls
- Video Filters and Noise Cancellation
- Screen sharing
- Picture in picture support
- Active speaker
- Custom events
- Geofencing
- Notifications and ringing calls
- Opus DTX & Red for reliable audio
- Webhooks & SQS
- Backstage mode
- Flexible permissions system
- Joining calls by ID, link or invite
- Enabling and disabling audio and video when in calls
- Flipping, Enabling and disabling camera in calls
- Enabling and disabling speakerphone in calls
- Push notification providers support
- Call recording
- Broadcasting to HLS

## Roadmap

### 0.4 milestone

- [x] Enhanced device management API
- [x] Composite layout for streaming and recording
- [x] Livestream Player
- [x] Screenshare Audio
- [x] Screen-sharing bitrate and FPS control
- [x] New Device Management API
- [x] SFU retries
- [x] Call Thumbnails

### 0.5 milestone

- [x] Fast-reconnects
- [x] Enhanced UI components and theming
- [x] Enhanced SDK build system
- [x] Typescript generics enhancements
- [x] Performance and bundle-size optimizations
- [x] Dynascale 2.0 (f resolution switches, resolution WebRTC handling)
- [x] Call analytics / stats
- [x] Video Filters

### 1.0 milestone

- [x] Transcriptions
- [x] Audio filters
- [x] Noise Cancellation

### Milestones

- [ ] Break-out rooms
- [ ] Waiting rooms
- [x] Closed captions
- [ ] Query call session endpoint
- [ ] Logging 2.0
- [x] Hardware-accelerated video encoding on supported platforms
- [x] Dynascale 2.0 (codec switching)
- [x] Improved stat collection and device performance metrics
- [ ] E2E testing platform
- [ ] Dynascale: turn off incoming video when the browser is in the background

## Contributing

- How can I submit a sample app?
  - Apps submissions are always welcome. 🥳 Open a PR with a proper description and we'll review it as soon as possible.
- Spot a bug 🕷 ?
  - We welcome code changes that improve the apps or fix a problem. Please make sure to follow all best practices and add tests if applicable before submitting a Pull Request on Github.
