/**
 * The props for the {@link LivestreamLayout} component.
 */
export type LivestreamLayoutProps = {
    /**
     * Whether the livestream is muted. Defaults to `false`.
     */
    muted?: boolean;
    /**
     * Whether to show the participant count. Defaults to `true`.
     */
    showParticipantCount?: boolean;
    /**
     * Whether to enable fullscreen mode. Defaults to `true`.
     */
    enableFullScreen?: boolean;
    /**
     * Whether to show the duration of the call. Defaults to `true`.
     */
    showDuration?: boolean;
    /**
     * Whether to show the live badge. Defaults to `true`.
     */
    showLiveBadge?: boolean;
    /**
     * Whether to show the speaker name. Defaults to `false`.
     */
    showSpeakerName?: boolean;
    /**
     * When set to `false` disables mirroring of the local participant's video.
     * @default true
     */
    mirrorLocalParticipantVideo?: boolean;
    /**
     * The props to pass to the floating participant element.
     */
    floatingParticipantProps?: LivestreamLayoutProps & {
        /**
         * The position of the floating participant element. Defaults to `top-right`.
         */
        position?: 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
    };
};
export declare const LivestreamLayout: {
    (props: LivestreamLayoutProps): import("react/jsx-runtime").JSX.Element;
    displayName: string;
};
/**
 * The props for the {@link LivestreamLayout} component.
 */
export type BackstageLayoutProps = {
    /**
     * Whether to show the counter for participants that joined before
     * the livestream went live. Defaults to `true`.
     */
    showEarlyParticipantCount?: boolean;
};
export declare const BackstageLayout: {
    (props: BackstageLayoutProps): import("react/jsx-runtime").JSX.Element;
    displayName: string;
};
