import { ParticipantViewProps } from '../ParticipantView';
import { ParticipantFilter, ParticipantPredicate } from './hooks';
export type PipLayoutProps = {
    /**
     * Whether to exclude the local participant from the grid.
     * @default false
     */
    excludeLocalParticipant?: boolean;
    /**
     * Predicate to filter call participants or a filter object.
     * @example
     * // With a predicate:
     * <PipLayout
     *   filterParticipants={p => p.roles.includes('student')}
     * />
     * @example
     * // With a filter object:
     * <PipLayout
     *   filterParticipants={{
     *     $or: [
     *       { roles: { $contains: 'student' } },
     *       { isPinned: true },
     *     ],
     *   }}
     * />
     */
    filterParticipants?: ParticipantPredicate | ParticipantFilter;
    /**
     * When set to `false` disables mirroring of the local partipant's video.
     * @default true
     */
    mirrorLocalParticipantVideo?: boolean;
} & Pick<ParticipantViewProps, 'ParticipantViewUI' | 'VideoPlaceholder'>;
export declare const PipLayout: {
    Pip: {
        (props: PipLayoutProps): import("react/jsx-runtime").JSX.Element | null;
        displayName: string;
    };
    Host: {
        (): import("react/jsx-runtime").JSX.Element;
        displayName: string;
    };
};
