import { BackstageLayoutProps, LivestreamLayoutProps } from '../../core';
export type LivestreamPlayerProps = {
    /**
     * The call type. Usually `livestream`.
     */
    callType: string;
    /**
     * The call ID.
     */
    callId: string;
    /**
     * Determines when the viewer joins the call.
     *
     * `"asap"` behavior means joining the call as soon as it is possible
     * (either the `join_ahead_time_seconds` setting allows it, or the user
     * has a the capability to join backstage).
     *
     * `"live"` behavior means joining the call when it goes live.
     *
     * @default "asap"
     */
    joinBehavior?: 'asap' | 'live';
    /**
     * The props for the {@link LivestreamLayout} component.
     */
    layoutProps?: LivestreamLayoutProps;
    /**
     * The props for the {@link BackstageLayout} component.
     */
    backstageProps?: BackstageLayoutProps;
    /**
     * Callback to handle errors while fetching or joining livestream.
     */
    onError?: (error: any) => void;
};
export declare const LivestreamPlayer: (props: LivestreamPlayerProps) => import("react/jsx-runtime").JSX.Element | null;
